@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -27,8 +27,6 @@
 #include <Core/Images/ImageProcessing.h>
 #include <Core/OrthancException.h>
 #include <Core/Toolbox.h>
-#include <Plugins/Samples/GdcmDecoder/OrthancImageWrapper.h>
-#include <Resources/ThirdParty/base64/base64.h>
 
 #include <boost/lexical_cast.hpp>
 #include <boost/algorithm/string/predicate.hpp>
@@ -127,8 +125,7 @@ namespace OrthancPlugins
   bool DecodedImageAdapter::Create(std::string& content,
                                    const std::string& uri)
   {
-    std::string message = "Decoding DICOM instance: " + uri;
-    OrthancPluginLogInfo(context_, message.c_str());
+    LOG(INFO) << "Decoding DICOM instance: " << uri;
 
     CompressionType type;
     uint8_t level;
@@ -140,7 +137,6 @@ namespace OrthancPlugins
       return false;
     }
 
-
     bool ok = false;
 
     Json::Value tags;
@@ -151,7 +147,9 @@ namespace OrthancPlugins
       throw Orthanc::OrthancException(Orthanc::ErrorCode_UnknownResource);
     }
 
-    std::auto_ptr<OrthancImageWrapper> image(new OrthancImageWrapper(context_, OrthancPluginDecodeDicomImage(context_, dicom.c_str(), dicom.size(), frameIndex)));
+    std::unique_ptr<OrthancImage> image(
+      new OrthancImage(OrthancPluginDecodeDicomImage(
+                         context_, dicom.c_str(), dicom.size(), frameIndex)));
 
     Json::Value json;
     if (GetCornerstoneMetadata(json, tags, *image))
@@ -180,9 +178,7 @@ namespace OrthancPlugins
     }
     else
     {
-      char msg[1024];
-      sprintf(msg, "Unable to decode the following instance: %s", uri.c_str());
-      OrthancPluginLogWarning(context_, msg);
+      LOG(WARNING) << "Unable to decode the following instance: " << uri;
       return false;
     }
   }
@@ -190,14 +186,14 @@ namespace OrthancPlugins
 
   bool DecodedImageAdapter::GetCornerstoneMetadata(Json::Value& result,
                                                    const Json::Value& tags,
-                                                   OrthancImageWrapper& image)
+                                                   OrthancImage& image)
   {
     using namespace Orthanc;
 
     float windowCenter, windowWidth;
 
     Orthanc::ImageAccessor accessor;
-    accessor.AssignReadOnly(OrthancPlugins::Convert(image.GetFormat()), image.GetWidth(),
+    accessor.AssignReadOnly(OrthancPlugins::Convert(image.GetPixelFormat()), image.GetWidth(),
                             image.GetHeight(), image.GetPitch(), image.GetBuffer());
 
     switch (accessor.GetFormat())
@@ -310,13 +306,13 @@ namespace OrthancPlugins
 
 
   bool  DecodedImageAdapter::EncodeUsingDeflate(Json::Value& result,
-                                                OrthancImageWrapper& image)
+                                                OrthancImage& image)
   {
     Orthanc::ImageAccessor accessor;
-    accessor.AssignReadOnly(OrthancPlugins::Convert(image.GetFormat()), image.GetWidth(),
+    accessor.AssignReadOnly(OrthancPlugins::Convert(image.GetPixelFormat()), image.GetWidth(),
                             image.GetHeight(), image.GetPitch(), image.GetBuffer());
 
-    std::auto_ptr<Orthanc::ImageBuffer> buffer;
+    std::unique_ptr<Orthanc::ImageBuffer> buffer;
 
     Orthanc::ImageAccessor converted;
 
@@ -362,9 +358,11 @@ namespace OrthancPlugins
     result["sizeInBytes"] = converted.GetSize();
 
     std::string z;
-    CompressUsingDeflate(z, image.GetContext(), converted.GetConstBuffer(), converted.GetSize());
-
-    result["Orthanc"]["PixelData"] = base64_encode(z);  
+    CompressUsingDeflate(z, GetGlobalContext(), converted.GetConstBuffer(), converted.GetSize());
+    
+    std::string s;
+    Orthanc::Toolbox::EncodeBase64(s, z);
+    result["Orthanc"]["PixelData"] = s;
 
     return true;
   }
@@ -419,14 +417,14 @@ namespace OrthancPlugins
 
 
   bool  DecodedImageAdapter::EncodeUsingJpeg(Json::Value& result,
-                                             OrthancImageWrapper& image,
+                                             OrthancImage& image,
                                              uint8_t quality /* between 0 and 100 */)
   {
     Orthanc::ImageAccessor accessor;
-    accessor.AssignReadOnly(OrthancPlugins::Convert(image.GetFormat()), image.GetWidth(),
+    accessor.AssignReadOnly(OrthancPlugins::Convert(image.GetPixelFormat()), image.GetWidth(),
                             image.GetHeight(), image.GetPitch(), image.GetBuffer());
 
-    std::auto_ptr<Orthanc::ImageBuffer> buffer;
+    std::unique_ptr<Orthanc::ImageBuffer> buffer;
 
     Orthanc::ImageAccessor converted;
 
@@ -482,9 +480,12 @@ namespace OrthancPlugins
     result["sizeInBytes"] = converted.GetSize();
 
     std::string jpeg;
-    WriteJpegToMemory(jpeg, image.GetContext(), converted, quality);
+    WriteJpegToMemory(jpeg, GetGlobalContext(), converted, quality);
 
-    result["Orthanc"]["PixelData"] = base64_encode(jpeg);  
+    std::string s;
+    Orthanc::Toolbox::EncodeBase64(s, jpeg);
+    result["Orthanc"]["PixelData"] = s;
+    
     return true;
   }
 }
