@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -27,7 +27,7 @@
 #include <stdint.h>
 #include <json/value.h>
 
-#include <Plugins/Samples/GdcmDecoder/OrthancImageWrapper.h>
+#include <Plugins/Samples/Common/OrthancPluginCppWrapper.h>
 
 
 namespace OrthancPlugins
@@ -49,13 +49,13 @@ namespace OrthancPlugins
 
     static bool GetCornerstoneMetadata(Json::Value& result,
                                        const Json::Value& tags,
-                                       OrthancImageWrapper& image);
+                                       OrthancImage& image);
 
     static bool EncodeUsingDeflate(Json::Value& result,
-                                   OrthancImageWrapper& image);
+                                   OrthancImage& image);
 
     static bool EncodeUsingJpeg(Json::Value& result,
-                                OrthancImageWrapper& image,
+                                OrthancImage& image,
                                 uint8_t quality /* between 0 and 100 */);
 
     OrthancPluginContext* context_;
