@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -25,7 +25,7 @@
 #include <Core/Toolbox.h>
 
 // Gain access to ORTHANC_PLUGINS_VERSION_IS_ABOVE if Orthanc SDK <= 1.3.0
-#include <Plugins/Samples/GdcmDecoder/GdcmImageDecoder.h>
+#include <Plugins/Samples/Common/OrthancPluginCppWrapper.h>
 
 #include <json/reader.h>
 #include <stdexcept>
